@@ -9,19 +9,19 @@
 #define _mysql_version_h
 
 #define PROTOCOL_VERSION            10
-#define MYSQL_SERVER_VERSION       "5.7.22-22"
-#define MYSQL_BASE_VERSION         "mysqld-5.7"
+#define MYSQL_SERVER_VERSION       "8.0.13-3"
+#define MYSQL_BASE_VERSION         "mysqld-8.0"
 #define MYSQL_SERVER_SUFFIX_DEF    ""
-#define FRM_VER                     6
-#define MYSQL_VERSION_ID            50722
+#define MYSQL_VERSION_ID            80013
 #define MYSQL_PORT                  3306
 #define MYSQL_PORT_DEFAULT          0
 #define MYSQL_UNIX_ADDR            "/run/mysqld/mysqld.sock"
 #define MYSQL_CONFIG_NAME          "my"
-#define MYSQL_COMPILATION_COMMENT  "MySQL Community Server (GPL)"
-#define LIBMYSQL_VERSION           "5.7.22-22"
-#define LIBMYSQL_VERSION_ID         50722
-#define SYS_SCHEMA_VERSION         "1.5.1"
+#define MYSQL_PERSIST_CONFIG_NAME  "mysqld-auto"
+#define MYSQL_COMPILATION_COMMENT  "Source distribution"
+#define LIBMYSQL_VERSION           "8.0.13-3"
+#define LIBMYSQL_VERSION_ID         80013
+#define SYS_SCHEMA_VERSION         "2.0.0"
 
 #ifndef LICENSE
 #define LICENSE                     GPL
